/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/


#pragma once

#include <QPushButton>
#include <QWidget>
#include <QString>
#include <QDebug>
#include <QMouseEvent>
#include <QWidget>
#include <QMap>
#include <QTimer>


/* Minimum  Width */
#define MINIMUM_BUTTON_SIZE 32

class Button : public QWidget {

	Q_OBJECT

public:
	explicit Button(unsigned int sym, QString name, QString altName = QString(), QWidget *parent = nullptr);

	/* X11 KeyCode for a given key */
	unsigned int keyCode();

	/* Continue pressed state if modifier */
	bool persist();

	/* Check if the key is pressed */
	bool isChecked();

	/* Set/Unset the key pressed state */
	void setChecked( bool );

	/* Resize the buttons */
	void resize( int width, int height );

	/* Switch the case */
	void changeCase();

private:
	/* Key label */
	QString mName;
	QString mAltName;

	QString text;

	/* X11 KeyCode for a given Key */
	unsigned int mKeyCode;

	/* Modifier flag */
	bool mModifier;

	/* Checked state */
	bool mChecked;

	/* Checkable flag */
	bool mCheckable;

	/* Pressed flag */
	bool mPressed;

	/* Persist flag */
	bool mPersist;

	/* Color of the Button */
	QColor mColor;

	/* Timer for long press */
	QTimer *longPressTimer;

	/* Stretch the button */
	qreal mStretch;

private Q_SLOTS:
	/* Auto-release key on long press */
	void autoReleaseKey();

	/* Continuous backspace */
	void repeatBackSpace();

protected:
	/* mouseReleaseEvent to simulate click */
	void mousePressEvent( QMouseEvent * );

	/* mouseReleaseEvent to simulate click */
	void mouseReleaseEvent( QMouseEvent * );

	/* paintEvent to have double labels */
	void paintEvent( QPaintEvent *pEvent );

Q_SIGNALS:
	/* Signal when the key is pressed */
	void sendKey( unsigned int );

	/* clicked() signal */
	void clicked();

	/* Emulate lonngPress signal */
	void longPressed();
};
