/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/

#pragma once

#include "suggestions.h"

#include <QPushButton>
#include <QMainWindow>
#include <QString>
#include <QScrollArea>
#include <QStackedWidget>

#include "button.h"
#include "trayicon.h"


class CoreKeyboard : public QMainWindow {

    Q_OBJECT

public:
	explicit CoreKeyboard();

private :
	void createKeyboard();
	void setWidgetProperties();
	void sendKey( unsigned int );

	void switchMode();

	void updatePredictions();

	QHash<int, Button *> modifiers;
	QScrollArea *suggestions;

	QPoint dragPoint;
	QPoint gpress;

	bool dragged = false;
	bool moved = false;

	QStackedWidget *keyStack;

	trayicon *trayIcon;

	QString typedLetters;
	QStringList predictions;

	Suggestions *dict;

	static QSettings *keymap;
	QFontMetrics *fm;

	int maxRows = 4;
	int maxCols = 11;

protected:
	void mouseMoveEvent( QMouseEvent * );
	void mousePressEvent( QMouseEvent * );
	void mouseReleaseEvent( QMouseEvent * );

	/* resizeEvent to resize font */
	void resizeEvent( QResizeEvent *rEvent );

private Q_SLOTS:
	void processKeyPress( unsigned int );
	void processLongKeyPress( unsigned int );

	void toggleShowHide();

	void suggestWords( unsigned int );
	void clearSuggestions();

	void shiftClicked();
	void switchPage();

	void typeWord();
};
